{% raw %}

/*  This file ads formatting for form elements in Tailwind https://nervous-knuth-fa9c3e.netlify.com/   additional form classes form-radio etc*/

.form-checkbox {
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
  display: inline-block;
  height: 1em;
  width: 1em;
  vertical-align: middle;
  border-width: 1px;
  border-radius: 0.25rem;
  background-color: #fff;
  -webkit-user-select: none;
     -moz-user-select: none;
      -ms-user-select: none;
          user-select: none;
}

input[type=checkbox]:focus + .form-checkbox, input[type=checkbox].form-checkbox:focus {
  outline: none;
  box-shadow: 0 0 0 3px rgba(66, 153, 225, 0.5);
}

input[type=checkbox]:focus:not(:checked) + .form-checkbox, input[type=checkbox].form-checkbox:focus:not(:checked) {
  border-color: #63b3ed;
}

input[type=checkbox]:checked + .form-checkbox, input[type=checkbox].form-checkbox:checked {
  background-color: currentColor;
  border-color: currentColor;
  background-image: url("data:image/svg+xml,%3Csvg viewBox='0 0 16 16' fill='%23fff' xmlns='http://www.w3.org/2000/svg'%3E%3Cpath d='M13.293 4.293a1 1 0 0 1 0 1.414L7 12a1 1 0 0 1-1.414 0L3.293 9.707a1 1 0 0 1 1.414-1.414l1.586 1.586 5.586-5.586a1 1 0 0 1 1.414 0z'/%3E%3C/svg%3E");
  background-size: cover;
  background-position: center;
  background-repeat: no-repeat;
}

.form-radio {
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
  display: inline-block;
  height: 1em;
  width: 1em;
  vertical-align: middle;
  border-width: 1px;
  border-radius: 9999px;
  background-color: #fff;
  -webkit-user-select: none;
     -moz-user-select: none;
      -ms-user-select: none;
          user-select: none;
}

input[type=radio]:focus + .form-radio, input[type=radio].form-radio:focus {
  outline: none;
  box-shadow: 0 0 0 3px rgba(66, 153, 225, 0.5);
}

input[type=radio]:focus:not(:checked) + .form-radio, input[type=radio].form-radio:focus:not(:checked) {
  border-color: #63b3ed;
}

input[type=radio]:checked + .form-radio, input[type=radio].form-radio:checked {
  background-color: currentColor;
  border-color: currentColor;
  background-image: url("data:image/svg+xml,%3Csvg viewBox='0 0 24 24' fill='%23ffffff' xmlns='http://www.w3.org/2000/svg'%3E%3Ccircle cx='12' cy='12' r='5'/%3E%3C/svg%3E");
  background-size: cover;
  background-position: center;
  background-repeat: no-repeat;
}

.form-input, .form-textarea, .form-multiselect {
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
  background-color: #fff;
  border-width: 1px;
  border-radius: 0.25rem;
  padding: 0.5rem 0.75rem;
  line-height: 1.5;
}

.form-input:focus, .form-textarea:focus, .form-multiselect:focus {
  outline: none;
  box-shadow: 0 0 0 3px rgba(66, 153, 225, 0.5);
  border-color: #63b3ed;
}

.form-select {
  background-color: #fff;
  border-width: 1px;
  border-radius: 0.25rem;
  padding-top: 0.5rem;
  padding-right: 2.5rem;
  padding-bottom: 0.5rem;
  padding-left: 0.75rem;
  line-height: 1.5;
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
  background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' fill='%23a0aec0' viewBox='0 0 24 24' %3E%3Cpath d='M15.3 9.3a1 1 0 0 1 1.4 1.4l-4 4a1 1 0 0 1-1.4 0l-4-4a1 1 0 0 1 1.4-1.4l3.3 3.29 3.3-3.3z'/%3E%3C/svg%3E");
  background-position: right 0.5rem center;
  background-repeat: no-repeat;
  background-size: 1.5em 1.5em;
}

.form-select::-ms-expand {
  display: none;
}

.form-select:focus {
  outline: none;
  box-shadow: 0 0 0 3px rgba(66, 153, 225, 0.5);
  border-color: #63b3ed;
}

{% endraw %}